==> v8.3.zip: ru_twords_ru_tw/bible/names/judea.md <==
# Иудея

## Факты:

Иудеей называлась одна из областей древнего Израиля.

* Название “Иудея” может использоваться для обозначения местности, расположенной в южной части древнего Израиля, к западу от Мёртвого моря. В некоторых переводах эта местность называется “Иудой”.
* Однако это название может использоваться для обозначения всех частей древнего Израиля, включая Галилею, Самарию, Перею, Идумею и Иудею (Иуду).
* Если в тексте слово “Иудея” употребляется для обозначения всех частей древнего Израиля, его можно заменить названием “иудейская страна”. Если оно употребляется для обозначения только одной части древнего Израиля, то можно использовать название “иудейская область” или “область Иудея”, поскольку эту территорию древнего Израиля населяло колено Иуды.

(Варианты перевода: [Как переводить имена](rc://*/ta/man/translate/translate-names))

(См. также: [Галилея, галилеянин](../names/galilee.md), [Едом, едомляне, Идумея, Сеир, Теман](../names/edom.md), [Иуда](../names/judah.md), [Иудея, иудейское царство](../names/kingdomofjudah.md), [Самария, самаряне](../names/samaria.md))

## Ссылки на библейский текст:

* [1 Фес. 2:14-16](rc://*/tn/help/1th/02/14)
* [Деян. 2:8-11](rc://*/tn/help/act/02/08)
* [Деян. 9:31-32](rc://*/tn/help/act/09/31)
* [Деян. 12:18-19](rc://*/tn/help/act/12/18)
* [Ин. 3:22-24](rc://*/tn/help/jhn/03/22)
* [Лк. 1:5-7](rc://*/tn/help/luk/01/05)
* [Лк. 4:42-44](rc://*/tn/help/luk/04/42)
* [Лк. 5:17](rc://*/tn/help/luk/05/17)
* [Мк. 10:1-4](rc://*/tn/help/mrk/10/01)
* [Мф. 2:1-3](rc://*/tn/help/mat/02/01)
* [Мф. 2:4-6](rc://*/tn/help/mat/02/04)
* [Мф. 2:22-23](rc://*/tn/help/mat/02/22)
* [Мф. 3:1-3](rc://*/tn/help/mat/03/01)
* [Мф. 19:1-2](rc://*/tn/help/mat/19/01)

## Данные о слове:

* Номера Стронга: H3061, G2453

==> v9.2.zip: ru_twords_ru_tw/bible/names/judea.md <==
# Иудея

## Факты:

Иудеей называлась одна из областей древнего Израиля.

* Название “Иудея” может использоваться для обозначения местности, расположенной в южной части древнего Израиля, к западу от Мёртвого моря. В некоторых переводах эта местность называется “Иудой”.
* Однако это название может использоваться для обозначения всех частей древнего Израиля, включая Галилею, Самарию, Перею, Идумею и Иудею (Иуду).
* Если в тексте слово “Иудея” употребляется для обозначения всех частей древнего Израиля, его можно заменить названием “иудейская страна”. Если оно употребляется для обозначения только одной части древнего Израиля, то можно использовать название “иудейская область” или “область Иудея”, поскольку эту территорию древнего Израиля населяло колено Иуды.

(Варианты перевода: [Как переводить имена](rc://ru/ta/man/translate/translate-names))

(См. также: [Галилея, галилеянин](../names/galilee.md), [Едом, едомляне, Идумея, Сеир, Теман](../names/edom.md), [Иуда](../names/judah.md), [Иудея, иудейское царство](../names/kingdomofjudah.md), [Самария, самаряне](../names/samaria.md))

## Ссылки на библейский текст:

* [1 Фес. 2:14-16](rc://ru/tn/help/1th/02/14)
* [Деян. 2:8-11](rc://ru/tn/help/act/02/08)
* [Деян. 9:31-32](rc://ru/tn/help/act/09/31)
* [Деян. 12:18-19](rc://ru/tn/help/act/12/18)
* [Ин. 3:22-24](rc://ru/tn/help/jhn/03/22)
* [Лк. 1:5-7](rc://ru/tn/help/luk/01/05)
* [Лк. 4:42-44](rc://ru/tn/help/luk/04/42)
* [Лк. 5:17](rc://ru/tn/help/luk/05/17)
* [Мк. 10:1-4](rc://ru/tn/help/mrk/10/01)
* [Мф. 2:1-3](rc://ru/tn/help/mat/02/01)
* [Мф. 2:4-6](rc://ru/tn/help/mat/02/04)
* [Мф. 2:22-23](rc://ru/tn/help/mat/02/22)
* [Мф. 3:1-3](rc://ru/tn/help/mat/03/01)
* [Мф. 19:1-2](rc://ru/tn/help/mat/19/01)

## Данные о слове:

* Номера Стронга: H3061, G2453
